<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet
version="1.0"
xmlns:d="http://docbook.org/ns/docbook"
xmlns:xl="http://www.w3.org/1999/xlink"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!--rst

NAME
====

produce a DocBook 5 with bibliograhy references sorted by years

EVOLUTIONS
==========

$Id$

- fplod 2008-09-17T10:40:43Z aedon.locean-ipsl.upmc.fr (Darwin)

  * project name from main.xml file instead of a fixed one

- fplod 2008-04-30T10:32:48Z aedon.locean-ipsl.upmc.fr (Darwin)

  * language inherited from biblio.xml

- fplod 2008-04-29T15:23:51Z aedon.locean-ipsl.upmc.fr (Darwin)

  * chgt for dbk5 in ++

- fplod 2008-04-29T07:46:20Z aedon.locean-ipsl.upmc.fr (Darwin)

  * chgt for dbk5 out

- fplod 2007-10-17T08:01:14Z aedon.locean-ipsl.upmc.fr (Darwin)

  * improve authors sort (diacriticals)

- fplod 2007-06-08T08:36:48Z aedon.locean-ipsl.upmc.fr (Darwin)

  * add total nb of publications in one cell. quite interesting usage of
    XPATH to determine mininum and maximum value of a element !

- fplod 2007-05-21T14:06:53Z aedon.locean-ipsl.upmc.fr (Darwin)

  * ajout de plot nbpub/years

- fplod 2007-05-04T08:02:29Z aedon.locean-ipsl.upmc.fr (Darwin)

  * externalisation de biblioentry
  * passage de itemizedlist  sect1 pour homognisation sur prsentation par auteur(et parce que je prfre)

- fplod 2007-04-02T08:53:30Z aedon.locean-ipsl.upmc.fr (Darwin)

  * journal dans biblioset

- fplod 2007-03-30T12:38:34Z aedon.locean-ipsl.upmc.fr (Darwin)

  * creation

-->

<xsl:output
 method="xml"
 indent="yes"
 omit-xml-declaration="no"/>

<xsl:include href="biblioentry_xml.xsl"/>

<xsl:variable name="list_years" select="///d:pubdate[not( self::node() = following::d:pubdate )]"/>

<xsl:variable name="project">
 <xsl:value-of select="document('main.xml')//d:keyword[@xml:id='project']"/>
</xsl:variable>

<xsl:template name="years">
<!--
creation of an informatable of nb years
each entry of the table is a link #year_xxxx
-->
<xsl:element name="informaltable">
 <xsl:attribute name="xml:id">years</xsl:attribute>
 <xsl:attribute name="summary">years of publications</xsl:attribute>
 <xsl:element name="tgroup">
  <xsl:variable name="nb_cols" select="count($list_years)"/>
  <xsl:attribute name="cols"><xsl:value-of select="$nb_cols"/></xsl:attribute>
  <xsl:attribute name="align">center</xsl:attribute>
  <xsl:attribute name="colsep">1</xsl:attribute>
  <xsl:attribute name="rowsep">1</xsl:attribute>
  <xsl:for-each select="///d:pubdate[not( self::node() = following::d:pubdate )]">
   <xsl:sort order="descending" data-type="number" select="."/>
   <xsl:element name="colspec">
    <xsl:attribute name="colname">year_<xsl:value-of select="."/></xsl:attribute>
   </xsl:element>
  </xsl:for-each>
  <xsl:element name="tbody">
   <xsl:element name="row">
    <xsl:for-each select="///d:pubdate[not( self::node() = following::d:pubdate )]">
     <xsl:sort order="descending" data-type="number" select="."/>
     <xsl:element name="entry">
      <xsl:attribute name="colname"><xsl:text>year_</xsl:text><xsl:value-of select="."/></xsl:attribute>
      <xsl:element name="link">
       <xsl:attribute name="xl:href"><xsl:text>#year_</xsl:text><xsl:value-of select="."/></xsl:attribute>
       <xsl:value-of select="."/>
      </xsl:element>
     </xsl:element>
    </xsl:for-each>
   </xsl:element>
   <xsl:element name="row">
    <xsl:for-each select="///d:pubdate[not( self::node() = following::d:pubdate )]">
     <xsl:sort order="descending" data-type="number" select="."/>
     <xsl:element name="entry">
      <xsl:attribute name="colname"><xsl:text>year_</xsl:text><xsl:value-of select="."/></xsl:attribute>
      <xsl:element name="emphasis">
       <xsl:attribute name="role">bold</xsl:attribute>
<xsl:variable name="nb_current">
 <xsl:variable name="current_year"><xsl:value-of select="."/></xsl:variable>
 <xsl:value-of select="count(/descendant::d:biblioentry[child::d:biblioset[child::d:pubdate=$current_year]])"/>
</xsl:variable>
       <xsl:value-of select="$nb_current"/>
      </xsl:element>
     </xsl:element>
    </xsl:for-each>
   </xsl:element>
   <xsl:variable name="year_min">
    <xsl:value-of select="///d:pubdate[not(. &gt; ///d:pubdate)]"/>
   </xsl:variable>
   <xsl:variable name="year_max">
    <xsl:value-of select="///d:pubdate[not(. &lt; ///d:pubdate)]"/>
   </xsl:variable>
   <xsl:element name="row">
    <xsl:element name="entry">
     <xsl:attribute name="namest"><xsl:value-of select="concat('year_',$year_max)"/></xsl:attribute>
      <xsl:attribute name="nameend"><xsl:value-of select="concat('year_',$year_min)"/></xsl:attribute>
     <xsl:element name="emphasis">
      <xsl:attribute name="role">bold</xsl:attribute>
       <xsl:value-of select="count(/descendant::d:biblioentry)"/>
     </xsl:element>
    </xsl:element>
   </xsl:element>
  </xsl:element>
 </xsl:element>
</xsl:element>
</xsl:template>

<xsl:template match="d:bibliography">

<xsl:element name="article">
<xsl:attribute name="version">5.0</xsl:attribute>
<xsl:attribute name="xmlns">http://docbook.org/ns/docbook</xsl:attribute>
<xsl:attribute name="xml:lang"><xsl:value-of select="@xml:lang"/></xsl:attribute>
<title><xsl:value-of select="$project"/> - Publications - Papers by years</title>
<info>
<authorgroup>
<author><personname><firstname>Sbastien</firstname> <surname>Masson</surname></personname></author>
<author><personname><firstname>Franoise</firstname> <surname>Pinsard</surname></personname></author>
<!--++-->
</authorgroup>
<keywordset>
<keyword><xsl:value-of select="$project"/></keyword>
</keywordset>
<!-- ++ date -->
</info>
<para xml:id="top">
This page intents to provide an exhaustive list of the papers that have used
<xsl:value-of select="$project"/> and/or results from them.
Obvioulsy many papers are missing.
If you find omissions or mistakes please ask some modification via
<xsl:element name="link">
 <xsl:attribute name="xl:href">
  <xsl:value-of select="'./main.php'"/>
 </xsl:attribute>
 <xsl:value-of select="document('main.xml')/d:article/d:title"/>
 <xsl:text>main page</xsl:text>
</xsl:element>.
</para>
<para>
You can also see <quote><xsl:value-of select="$project"/> - Publications - Papers</quote> sorted by
authors in
<xsl:element name="link">
 <xsl:attribute name="xl:href">
  <xsl:value-of select="'./superbib02.html'"/>
 </xsl:attribute>
 <xsl:text>one big document </xsl:text>
</xsl:element>
<xsl:text> or in </xsl:text>
<xsl:element name="link">
 <xsl:attribute name="xl:href">
  <xsl:value-of select="'../many/superbib01/index.html'"/>
 </xsl:attribute>
 <xsl:text>several </xsl:text>
</xsl:element> <xsl:text> (one by author)</xsl:text>.
</para>

<xsl:call-template name="para_lastupdate_bib">
 <xsl:with-param name="language" select="@xml:lang"/>
 <xsl:with-param name="date" select="d:info/d:date"/>
</xsl:call-template>

<xsl:call-template name="years"/>

<figure xml:id="fig_pubbyyears"><title>Nb of publications by years</title>
<mediaobject>
<imageobject>
<imagedata fileref="../../images/years.png" format="PNG"/>
</imageobject>
<textobject><phrase>[years.png]</phrase></textobject>
</mediaobject>
</figure>

<sect1 xml:id="intro">
<title>Introduction</title>
<para>
This document provide bibliography sorted by year.
</para>
</sect1>

   <!-- loop on years -->
   <xsl:for-each select="$list_years">
    <xsl:sort order="descending" data-type="number" select="."/>
    <xsl:call-template name="one_year">
     <xsl:with-param name="year" select="."/>
    </xsl:call-template>
   </xsl:for-each>
</xsl:element>
</xsl:template>

<xsl:template match="d:info/d:date"/>
<xsl:template match="d:bibliography/d:title"/>

<xsl:template name="one_year">
<xsl:param name="year"/>
<!--
 <xsl:message>call template avec <xsl:value-of select="$year"/></xsl:message>
 <xsl:message>noeud courant <xsl:value-of select="name(.)"/></xsl:message>
 <xsl:message>
year_<xsl:value-of select="$year"/> : <xsl:value-of select="count(/descendant::d:biblioentry[child::d:biblioset[child::d:pubdate=$year]]) + count(/descendant::d:biblioentry[child::d:date=$year])"/>
</xsl:message>
-->
 <xsl:element name="sect1">
  <xsl:attribute name="xml:id"><xsl:value-of select="concat('year_',$year)"/></xsl:attribute>
  <xsl:element name="title">
   <xsl:value-of select="$year"/>
   <xsl:element name="link">
   <xsl:attribute name="xl:href"><xsl:text>#top</xsl:text></xsl:attribute>
   <xsl:element name="inlinemediaobject">
     <xsl:element name="imageobject">
      <xsl:element name="imagedata">
       <xsl:attribute name="fileref">../../images/globalicondl11x10_up.gif</xsl:attribute>
      </xsl:element>
     </xsl:element>
     <xsl:element name="textobject">
      <xsl:element name="phrase">
       <xsl:text>top</xsl:text>
      </xsl:element>
     </xsl:element>
    </xsl:element>
   </xsl:element>
  </xsl:element>
  <orderedlist>
   <xsl:for-each select="/descendant::d:biblioentry[child::d:biblioset[child::d:pubdate=$year]]|/descendant::d:biblioentry[child::d:date=$year]">
    <xsl:sort order="ascending" data-type="text" select="translate(./authorgroup/author/personname,'abcdefghijklmnopqrstuvwxyz ','ABCDEFGHIJKLMNOPQRSTUVWXYZ_EECAUEONO')"/>
    <xsl:call-template name="one_biblioentry">
     <xsl:with-param name="visu_modif" select="'visu'"/>
     <xsl:with-param name="type" select="'raw'"/>
     <xsl:with-param name="my_biblioentry" select="."/>
    </xsl:call-template>
   </xsl:for-each>
  </orderedlist>
 </xsl:element>
</xsl:template>

</xsl:stylesheet>
