<?xml version="1.0" encoding="iso-8859-1"?>
<xsl:stylesheet
xmlns:d="http://docbook.org/ns/docbook"
xmlns:xl="http://www.w3.org/1999/xlink"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
version="1.0">

<!--rst
NAME
====
produce one DocBook 5 with bibliograhy references of one author in each

this DocBook will be chuncked for html output

EVOLUTIONS
==========

$Id$

- fplod 2008-09-17T09:49:51Z aedon.locean-ipsl.upmc.fr (Darwin)

  * project name from main.xml file instead of a fixed one

- fplod 2008-04-30T14:52:20Z aedon.locean-ipsl.upmc.fr (Darwin)

  * language inherited from biblio.xml

- fplod 2008-04-29T15:57:17Z aedon.locean-ipsl.upmc.fr (Darwin)

  * chgt for dbk5 in

- fplod 2008-04-29T08:20:09Z aedon.locean-ipsl.upmc.fr (Darwin)

  * chgt for dbk5 out

- fplod 2007-10-17T08:03:44Z aedon.locean-ipsl.upmc.fr (Darwin)

  * improve sort (diacriticals)

- fplod 2007-05-18T14:57:52Z aedon.locean-ipsl.upmc.fr (Darwin)

  * modif gestion id

- fplod 2007-05-16T15:19:57Z aedon.locean-ipsl.upmc.fr (Darwin)

  * correction pour homonymes partiels

- fplod 2007-05-04T09:23:05Z aedon.locean-ipsl.upmc.fr (Darwin)

  * cration  partir de bibnemomaf02_xml.xsl mais liens externes
-->

<xsl:output
 method="xml"
 indent="yes"
 omit-xml-declaration="no"/>


<xsl:include href="firstname_id.xsl"/>
<xsl:include href="surname_id.xsl"/>
<xsl:include href="table_authors.xsl"/>
<xsl:include href="biblioentry_xml.xsl"/>

<xsl:variable name="list_author_ids" select="///d:author[not( self::node() = following::d:author )]"/>
<xsl:variable name="project">
 <xsl:value-of select="document('main.xml')//d:keyword[@xml:id='project']"/>
</xsl:variable>

<xsl:template match="d:bibliography">

<xsl:element name="article">
<xsl:attribute name="version">5.0</xsl:attribute>
<xsl:attribute name="xmlns">http://docbook.org/ns/docbook</xsl:attribute>
<xsl:attribute name="xml:lang"><xsl:value-of select="@xml:lang"/></xsl:attribute>
<title><xsl:value-of select="$project"/> - Publications - Papers by authors</title>
<info>
<authorgroup>
<author><personname><firstname>Sbastien</firstname> <surname>Masson</surname></personname></author>
<author><personname><firstname>Franoise</firstname> <surname>Pinsard</surname></personname></author>
<!--++-->
</authorgroup>
<keywordset>
<keyword><xsl:value-of select="$project"/></keyword>
</keywordset>
<!-- ++ date -->
</info>
<para>
 This page intents to provide an exhaustive list of the papers that have used <xsl:value-of select="$project"/> and/or results from them. Obvioulsy many papers are missing. If you find omissions or mistakes please ask some modification via
<xsl:element name="link">
 <xsl:attribute name="xl:href">
  <xsl:value-of select="'../../one/main.php'"/>
 </xsl:attribute>
 <xsl:value-of select="document('main.xml')/d:article/d:title"/>
 <xsl:text>main page</xsl:text>
</xsl:element>.
</para>
<para>
You can also see <quote><xsl:value-of select="$project"/> - Publications - Papers</quote> sorted by
<xsl:element name="link">
 <xsl:attribute name="xl:href">
  <xsl:value-of select="'../../one/superbib01.html'"/>
 </xsl:attribute>
<xsl:text>years</xsl:text>
</xsl:element>.
</para>
<xsl:call-template name="para_lastupdate_bib">
 <xsl:with-param name="language" select="@xml:lang"/>
 <xsl:with-param name="date" select="d:info/d:date"/>
</xsl:call-template>

<sect1 xml:id="intro">
<title>Introduction</title>
<para>
This document provide bibliography sorted by author's id (<emphasis>SURNAME_f</emphasis>).
</para>

<xsl:call-template name="table_authors">
<xsl:with-param name="linktype" select="'external'"/>
</xsl:call-template>
</sect1>

<!-- loop on author_ids -->
<xsl:for-each select="$list_author_ids">
<xsl:sort order="ascending" data-type="text" select="translate(.,'abcdefghijklmnopqrstuvwxyz ', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ_EECAUEONO')"/>
<xsl:variable name="author_id2">
<xsl:call-template name="surname_id">
 <xsl:with-param name="surname" select="d:personname/d:surname"/>
</xsl:call-template>
<xsl:text>_</xsl:text>
<xsl:call-template name="firstname_id">
 <xsl:with-param name="firstname" select="d:personname/d:firstname"/>
</xsl:call-template>
</xsl:variable>
<!--
<xsl:message terminate="no">
noeud courant <xsl:value-of select="name(.)"/>
author <xsl:value-of select="."/>
author_id2 <xsl:value-of select="$author_id2"/>
</xsl:message>
-->
<xsl:call-template name="one_author_id">
<xsl:with-param name="author_id" select="$author_id2"/>
<xsl:with-param name="author_name" select="."/>
</xsl:call-template>
</xsl:for-each>

</xsl:element>
</xsl:template>

<xsl:template match="d:info/d:date"/>
<xsl:template match="d:bibliography/d:title"/>

<xsl:template name="one_author_id">
<xsl:param name="author_id"/>
<xsl:param name="author_name"/>
<xsl:element name="sect1">
<xsl:attribute name="xml:id">
<xsl:value-of select="$author_id"/>
</xsl:attribute>
<xsl:element name="title">
<xsl:value-of select="normalize-space($author_name/d:personname/d:firstname)"/><xsl:text> </xsl:text><xsl:value-of select="normalize-space($author_name/d:personname/d:surname)"/>
</xsl:element>
  <xsl:element name="orderedlist">
  <!--
    <xsl:for-each select="/descendant::d:biblioentry[descendant::d:author=$author_name]">
  -->
   <xsl:for-each select="//d:biblioentry">
    <xsl:sort order="descending" data-type="number" select="./d:biblioset/d:pubdate"/>

    <xsl:for-each select="descendant::d:author">
     <xsl:sort order="ascending" data-type="text" select="translate(./d:personname,'abcdefghijklmnopqrstuvwxyz ', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ_EECAUEONO')"/>
     <xsl:variable name="author_id2">
<xsl:call-template name="surname_id">
 <xsl:with-param name="surname" select="d:personname/d:surname"/>
</xsl:call-template>
<xsl:text>_</xsl:text>
<xsl:call-template name="firstname_id">
 <xsl:with-param name="firstname" select="d:personname/d:firstname"/>
</xsl:call-template>
     </xsl:variable>

<!--
     <xsl:message terminate="no">
      ref #<xsl:value-of select="position()"/>
      _id appel <xsl:value-of select="$author_id"/>
      _id fabrique <xsl:value-of select="$author_id2"/>
      egal ? <xsl:value-of select="$author_id2 = $author_id"/>
     </xsl:message>
-->
     <xsl:if test="$author_id2 = $author_id">
  <xsl:call-template name="one_biblioentry">
   <xsl:with-param name="visu_modif" select="'visu'"/>
   <xsl:with-param name="type" select="'raw'"/>
   <xsl:with-param name="my_biblioentry" select="ancestor::d:biblioentry"/>
  </xsl:call-template>
     </xsl:if>
    </xsl:for-each>
   </xsl:for-each>
  </xsl:element>
 </xsl:element>
</xsl:template>

</xsl:stylesheet>
